@@ -51,13 +51,13 @@ class AboutDialog(gtk.AboutDialog):
         # translation at your discretion.
         self.set_program_name(_("NFO Viewer"))
         self.set_version(nfoview.__version__)
-        self.set_copyright(u"Copyright \xa9 2005-2010 Osmo Salomaa")
+        self.set_copyright(u"Copyright \xa9 2005-2011 Osmo Salomaa")
         self.set_comments(_("Viewer for NFO files"))
         self.set_license(_license)
         self.set_wrap_license(True)
         self.set_website("http://home.gna.org/nfoview/")
         self.set_website_label(_("NFO Viewer Website"))
-        self.set_authors(("Osmo Salomaa <otsaloma@cc.hut.fi>",))
+        self.set_authors(("Osmo Salomaa <otsaloma@iki.fi>",))
         self.set_logo_icon_name("nfoview")
 
         # Translators: This is a special message that shouldn't be translated
